<?php
/**
 * Theme Options related to featured section.
 *
 * @package Easy_Commerce
 */

$default = easy_commerce_get_default_theme_options();

// Add Panel.
$wp_customize->add_panel( 'theme_featured_section_panel',
	array(
	'title'      => __( 'Featured Section', 'easy-commerce-pro' ),
	'priority'   => 100,
	'capability' => 'edit_theme_options',
	)
);

// Featured content type section.
$wp_customize->add_section( 'section_theme_featured_basic_settings',
	array(
	'title'      => __( 'Basic Settings', 'easy-commerce-pro' ),
	'priority'   => 100,
	'capability' => 'edit_theme_options',
	'panel'      => 'theme_featured_section_panel',
	)
);

// Setting featured_section_status.
$wp_customize->add_setting( 'theme_options[featured_section_status]',
	array(
	'default'           => $default['featured_section_status'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[featured_section_status]',
	array(
	'label'       => __( 'Enable Featured Section', 'easy-commerce-pro' ),
	'description' => __( 'This will be displayed in static front page.', 'easy-commerce-pro' ),
	'section'     => 'section_theme_featured_basic_settings',
	'type'        => 'checkbox',
	'priority'    => 100,
	)
);

// Setting featured_left_heading.
$wp_customize->add_setting( 'theme_options[featured_left_heading]',
	array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Heading_Control( $wp_customize, 'theme_options[featured_left_heading]',
		array(
			'label'           => __( 'Left Section', 'easy-commerce-pro' ),
			'section'         => 'section_theme_featured_basic_settings',
			'settings'        => 'theme_options[featured_left_heading]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_section_active',
		)
	)
);

// Setting featured_left_message.
$wp_customize->add_setting( 'theme_options[featured_left_message]',
	array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Message_Control( $wp_customize, 'theme_options[featured_left_message]',
		array(
			'description'     => sprintf( __( 'If Widget option selected, widgets in %s will be displayed.', 'easy-commerce-pro' ), '<a href="javascript:wp.customize.panel( \'widgets\' ).focus();"><em>Featured Section Left</em></a>' ),
			'section'         => 'section_theme_featured_basic_settings',
			'settings'        => 'theme_options[featured_left_message]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_section_active',
		)
	)
);

// Setting featured_section_left_content_type.
$wp_customize->add_setting( 'theme_options[featured_section_left_content_type]',
	array(
	'default'           => $default['featured_section_left_content_type'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_select',
	)
);
$wp_customize->add_control( 'theme_options[featured_section_left_content_type]',
	array(
	'label'           => esc_html__( 'Content Type', 'easy-commerce-pro' ),
	'section'         => 'section_theme_featured_basic_settings',
	'type'            => 'radio',
	'priority'        => 100,
	'choices'         => easy_commerce_get_featured_section_content_types_options(),
	'active_callback' => 'easy_commerce_is_featured_section_active',
	)
);

// Setting featured_right_heading.
$wp_customize->add_setting( 'theme_options[featured_right_heading]',
	array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Heading_Control( $wp_customize, 'theme_options[featured_right_heading]',
		array(
			'label'           => __( 'Right Section', 'easy-commerce-pro' ),
			'section'         => 'section_theme_featured_basic_settings',
			'settings'        => 'theme_options[featured_right_heading]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_section_active',
		)
	)
);

// Setting featured_right_message.
$wp_customize->add_setting( 'theme_options[featured_right_message]',
	array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Message_Control( $wp_customize, 'theme_options[featured_right_message]',
		array(
			'description'     => sprintf( __( 'This section will display widgets in %s widget area.', 'easy-commerce-pro' ), '<a href="javascript:wp.customize.panel( \'widgets\' ).focus();"><em>Featured Section Right</em></a>' ),
			'section'         => 'section_theme_featured_basic_settings',
			'settings'        => 'theme_options[featured_right_message]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_section_active',
		)
	)
);

// Slider Type Section.
$wp_customize->add_section( 'section_theme_slider_type',
	array(
	'title'      => __( 'Slider Type', 'easy-commerce-pro' ),
	'priority'   => 100,
	'capability' => 'edit_theme_options',
	'panel'      => 'theme_featured_section_panel',
	)
);

// Setting featured_slider_type.
$wp_customize->add_setting( 'theme_options[featured_slider_type]',
	array(
	'default'           => $default['featured_slider_type'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_select',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_type]',
	array(
	'label'    => __( 'Select Slider Type', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_type',
	'type'     => 'select',
	'priority' => 100,
	'choices'  => easy_commerce_get_featured_slider_type(),
	)
);

// Setting featured_slider_number.
$wp_customize->add_setting( 'theme_options[featured_slider_number]',
	array(
	'default'           => $default['featured_slider_number'],
	'capability'        => 'edit_theme_options',
	'transport'         => 'postMessage',
	'sanitize_callback' => 'easy_commerce_sanitize_number_range',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_number]',
	array(
	'label'           => __( 'No of Slides', 'easy-commerce-pro' ),
	'description'     => __( 'Enter number between 1 and 20. Save and refresh the page if No of Slides is changed.', 'easy-commerce-pro' ),
	'section'         => 'section_theme_slider_type',
	'type'            => 'number',
	'priority'        => 100,
	'active_callback' => 'easy_commerce_is_non_demo_featured_slider_active',
	'input_attrs'     => array( 'min' => 1, 'max' => 20, 'step' => 1, 'style' => 'width: 55px;' ),
	)
);

$featured_slider_number = absint( easy_commerce_get_option( 'featured_slider_number' ) );

if ( $featured_slider_number > 0 ) {
	for ( $i = 1; $i <= $featured_slider_number; $i++ ) {
		$wp_customize->add_setting( "theme_options[featured_slider_page_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_page_' . $i ] ) ? $default[ 'featured_slider_page_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'easy_commerce_sanitize_dropdown_pages',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_page_$i]",
			array(
			'label'           => __( 'Featured Page', 'easy-commerce-pro' ) . ' - ' . $i,
			'section'         => 'section_theme_slider_type',
			'type'            => 'dropdown-pages',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_page_slider_active',
			)
		);
	} // End for loop.
}

// For multiple posts.
if ( $featured_slider_number > 0 ) {
	for ( $i = 1; $i <= $featured_slider_number; $i++ ) {
		$wp_customize->add_setting( "theme_options[featured_slider_post_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_post_' . $i ] ) ? $default[ 'featured_slider_post_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'easy_commerce_sanitize_post_id',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_post_$i]",
			array(
			'label'           => __( 'Featured Post', 'easy-commerce-pro' ) . ' #' . $i,
			'description'     => __( 'Enter Post ID', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'text',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_post_slider_active',
			'input_attrs'     => array( 'style' => 'width: 70px;' ),
			)
		);
	} // End for loop.
}

// For multiple images.
if ( $featured_slider_number > 0 ) {
	for ( $i = 1; $i <= $featured_slider_number; $i++ ) {

		$wp_customize->add_setting( "theme_options[featured_slider_image_heading_$i]",
			array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			new easy_commerce_Heading_Control( $wp_customize, "theme_options[featured_slider_image_heading_$i]",
				array(
					'label'           => __( 'Slide', 'easy-commerce-pro' ) . ' #' . $i,
					'section'         => 'section_theme_slider_type',
					'settings'        => "theme_options[featured_slider_image_heading_$i]",
					'priority'        => 100,
					'active_callback' => 'easy_commerce_is_featured_image_slider_active',
				)
			)
		);

		$wp_customize->add_setting( "theme_options[featured_slider_image_photo_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_photo_' . $i ] ) ? $default[ 'featured_slider_image_photo_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, "theme_options[featured_slider_image_photo_$i]",
				array(
					'label'           => __( 'Image', 'easy-commerce-pro' ),
					'section'         => 'section_theme_slider_type',
					'settings'        => "theme_options[featured_slider_image_photo_$i]",
					'priority'        => 100,
					'active_callback' => 'easy_commerce_is_featured_image_slider_active',
				)
			)
		);

		$wp_customize->add_setting( "theme_options[featured_slider_image_title_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_title_' . $i ] ) ? $default[ 'featured_slider_image_title_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'easy_commerce_sanitize_textarea_content',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_title_$i]",
			array(
			'label'           => __( 'Title', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'text',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);

		$wp_customize->add_setting( "theme_options[featured_slider_image_caption_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_caption_' . $i ] ) ? $default[ 'featured_slider_image_caption_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_caption_$i]",
			array(
			'label'           => __( 'Caption', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'textarea',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);

		$wp_customize->add_setting( "theme_options[featured_slider_image_url_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_url_' . $i ] ) ? $default[ 'featured_slider_image_url_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_url_$i]",
			array(
			'label'           => __( 'Link', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'url',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);

		$wp_customize->add_setting( "theme_options[featured_slider_image_primary_button_text_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_primary_button_text_' . $i ] ) ? $default[ 'featured_slider_image_primary_button_text_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_primary_button_text_$i]",
			array(
			'label'           => __( 'Primary Button Text', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'text',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);
		$wp_customize->add_setting( "theme_options[featured_slider_image_primary_button_url_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_primary_button_url_' . $i ] ) ? $default[ 'featured_slider_image_primary_button_url_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_primary_button_url_$i]",
			array(
			'label'           => __( 'Primary Button URL', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'url',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);

		$wp_customize->add_setting( "theme_options[featured_slider_image_secondary_button_text_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_secondary_button_text_' . $i ] ) ? $default[ 'featured_slider_image_secondary_button_text_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_secondary_button_text_$i]",
			array(
			'label'           => __( 'Secondary Button Text', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'text',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);
		$wp_customize->add_setting( "theme_options[featured_slider_image_secondary_button_url_$i]",
			array(
			'default'           => isset( $default[ 'featured_slider_image_secondary_button_url_' . $i ] ) ? $default[ 'featured_slider_image_secondary_button_url_' . $i ] : '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( "theme_options[featured_slider_image_secondary_button_url_$i]",
			array(
			'label'           => __( 'Secondary Button URL', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'type'            => 'url',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_image_slider_active',
			)
		);

	} // End for loop.
}

// Setting featured_slider_category.
$wp_customize->add_setting( 'theme_options[featured_slider_category]',
	array(
		'default'           => $default['featured_slider_category'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[featured_slider_category]',
		array(
			'label'           => __( 'Select Category', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'settings'        => 'theme_options[featured_slider_category]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_category_slider_active',
		)
	)
);

// Setting featured_slider_product_category.
$wp_customize->add_setting( 'theme_options[featured_slider_product_category]',
	array(
		'default'           => $default['featured_slider_product_category'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[featured_slider_product_category]',
		array(
			'label'           => __( 'Select Product Category', 'easy-commerce-pro' ),
			'section'         => 'section_theme_slider_type',
			'settings'        => 'theme_options[featured_slider_product_category]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_product_category_slider_active',
			'taxonomy'        => 'product_cat',
		)
	)
);

// Setting featured_slider_tag.
$wp_customize->add_setting( 'theme_options[featured_slider_tag]',
	array(
	'default'           => $default['featured_slider_tag'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[featured_slider_tag]',
		array(
			'label'           => __( 'Select Tag', 'easy-commerce-pro' ),
			'taxonomy'        => 'post_tag',
			'section'         => 'section_theme_slider_type',
			'settings'        => 'theme_options[featured_slider_tag]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_tag_slider_active',
		)
	)
);

// Setting featured_slider_product_tag.
$wp_customize->add_setting( 'theme_options[featured_slider_product_tag]',
	array(
	'default'           => $default['featured_slider_product_tag'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Easy_Commerce_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[featured_slider_product_tag]',
		array(
			'label'           => __( 'Select Product Tag', 'easy-commerce-pro' ),
			'taxonomy'        => 'product_tag',
			'section'         => 'section_theme_slider_type',
			'settings'        => 'theme_options[featured_slider_product_tag]',
			'priority'        => 100,
			'active_callback' => 'easy_commerce_is_featured_product_tag_slider_active',
		)
	)
);

// Setting featured_slider_read_more_text.
$wp_customize->add_setting( 'theme_options[featured_slider_read_more_text]',
	array(
	'default'           => $default['featured_slider_read_more_text'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_read_more_text]',
	array(
	'label'           => __( 'Read More Text', 'easy-commerce-pro' ),
	'section'         => 'section_theme_slider_type',
	'type'            => 'text',
	'priority'        => 100,
	'active_callback' => 'easy_commerce_is_featured_slider_active_non_demo_non_image',
	)
);

// Slider Options Section.
$wp_customize->add_section( 'section_theme_slider_options',
	array(
	'title'      => __( 'Slider Options', 'easy-commerce-pro' ),
	'priority'   => 100,
	'capability' => 'edit_theme_options',
	'panel'      => 'theme_featured_section_panel',
	)
);

// Setting featured_slider_transition_effect.
$wp_customize->add_setting( 'theme_options[featured_slider_transition_effect]',
	array(
	'default'           => $default['featured_slider_transition_effect'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_select_liberal',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_transition_effect]',
	array(
	'label'    => __( 'Transition Effect', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_options',
	'type'     => 'select',
	'priority' => 100,
	'choices'  => easy_commerce_get_featured_slider_transition_effects(),
	)
);
// Setting featured_slider_transition_delay.
$wp_customize->add_setting( 'theme_options[featured_slider_transition_delay]',
	array(
	'default'           => $default['featured_slider_transition_delay'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_number_range',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_transition_delay]',
	array(
	'label'       => __( 'Transition Delay', 'easy-commerce-pro' ),
	'description' => __( 'in seconds', 'easy-commerce-pro' ),
	'section'     => 'section_theme_slider_options',
	'type'        => 'number',
	'priority'    => 100,
	'input_attrs' => array( 'min' => 1, 'max' => 10, 'step' => 1, 'style' => 'width: 55px;' ),
	)
);
// Setting featured_slider_transition_duration.
$wp_customize->add_setting( 'theme_options[featured_slider_transition_duration]',
	array(
	'default'           => $default['featured_slider_transition_duration'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_number_range',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_transition_duration]',
	array(
	'label'       => __( 'Transition Duration', 'easy-commerce-pro' ),
	'description' => __( 'in seconds', 'easy-commerce-pro' ),
	'section'     => 'section_theme_slider_options',
	'type'        => 'number',
	'priority'    => 100,
	'input_attrs' => array( 'min' => 1, 'max' => 10, 'step' => 1, 'style' => 'width: 55px;' ),
	)
);
// Setting featured_slider_enable_caption.
$wp_customize->add_setting( 'theme_options[featured_slider_enable_caption]',
	array(
	'default'           => $default['featured_slider_enable_caption'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_enable_caption]',
	array(
	'label'    => __( 'Enable Caption', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_options',
	'type'     => 'checkbox',
	'priority' => 100,
	)
);
// Setting featured_slider_enable_arrow.
$wp_customize->add_setting( 'theme_options[featured_slider_enable_arrow]',
	array(
	'default'           => $default['featured_slider_enable_arrow'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_enable_arrow]',
	array(
	'label'    => __( 'Enable Arrow', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_options',
	'type'     => 'checkbox',
	'priority' => 100,
	)
);
// Setting featured_slider_enable_pager.
$wp_customize->add_setting( 'theme_options[featured_slider_enable_pager]',
	array(
	'default'           => $default['featured_slider_enable_pager'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_enable_pager]',
	array(
	'label'    => __( 'Enable Pager', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_options',
	'type'     => 'checkbox',
	'priority' => 100,
	)
);
// Setting featured_slider_enable_autoplay.
$wp_customize->add_setting( 'theme_options[featured_slider_enable_autoplay]',
	array(
	'default'           => $default['featured_slider_enable_autoplay'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_enable_autoplay]',
	array(
	'label'    => __( 'Enable Autoplay', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_options',
	'type'     => 'checkbox',
	'priority' => 100,
	)
);

// Setting featured_slider_enable_overlay.
$wp_customize->add_setting( 'theme_options[featured_slider_enable_overlay]',
	array(
	'default'           => $default['featured_slider_enable_overlay'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'easy_commerce_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[featured_slider_enable_overlay]',
	array(
	'label'    => __( 'Enable Overlay', 'easy-commerce-pro' ),
	'section'  => 'section_theme_slider_options',
	'type'     => 'checkbox',
	'priority' => 100,
	)
);
